from random import random

def matrixcreate(R,C, fillvalue=0):
    """Crea una matrice di dimensione RxC

    La matrice viene riempita di zeri, a meno che il parametro
    opzionale fillvalue non abbia un valore differente.
    """
    M=[]
    for i in range(R):
        M.append( [fillvalue]*C)
    return M

def matrixrandomfill(M):
    """Randomizza la matrice

    Riempie le celle della matrice con valori casuali
    scelti uniformemente in [0,1)
    """
    R,C = len(M), len(M[0])
    for r in range(R):
        for c in range(C):
            M[r][c]=random()

def matrixprint(M):
    "Stampa la matrice"
    R,C = len(M), len(M[0])
    for r in range(R):
        for c in range(C):
            s = "{:.2f}".format(M[r][c])
            print(s,end=' ')
        print()

def matrixI(n):
    """Matrice identità

    Dato un intero positivo n, crea la matrice identità di ordine n
    """
    I = matrixcreate(n,n)
    for i in range(n):
        I[i][i] = 1.0
    return I

def matrixsum(M):
    "Somma tutti i valori contenuti in una matrice"
    R,C = len(M), len(M[0])
    acc = 0
    for r in range(R):
        for c in range(C):
            acc += M[r][c]
    return acc

def matrixtranspose(A):
    "Produce la matrice trasposta di A"
    R,C = len(A), len(A[0])
    B = matrixcreate(C,R)
    for r in range(R):
        for c in range(C):
            B[c][r] = A[r][c]
    return B

def matrix_maxrow(A):
    """Posizione della riga di somma massima

    Data la matrice A restituisce l'indice di riga che
    corrisponde una riga che ha massima somma degli elementi.
    """
    R = len(A)
    rowmax=0
    rowval=sum(A[0])
    for r in range(1,R):
        tmp = sum(A[r])
        if tmp>rowval:
            rowmax=r
            rowval=tmp
    return rowmax
